[![Build Status](https://travis-ci.com/cs207-group19/cs207-FinalProject.svg?branch=master)](https://travis-ci.com/cs207-group19/cs207-FinalProject.svg?branch=master)

[![Coverage Status](https://coveralls.io/repos/github/cs207-group19/cs207-FinalProject/badge.svg?branch=master)](https://coveralls.io/github/cs207-group19/cs207-FinalProject?branch=master)

[![Documentation Status](https://readthedocs.org/projects/cs-207-final-project-group-19/badge/?version=latest)](https://cs-207-final-project-group-19.readthedocs.io/en/latest/?badge=latest)

Note: if the coverage % seems outdated, one can clear browser cache, or click the badge which links to the coverage site, or run the command `pytest test_DeriveAlive.py` from the `tests/` folder.

# cs207-FinalProject
Repository for CS 207 Final Project (Autodifferentiation), Group 19, Fall 2018

### Group 19
### Group name: DeriveAlive

### Group members: Stephen Slater, Chen Shi, Yue Sun

Welcome to DeriveAlive! This is a package for autodifferentiation. It includes several additional features making use of autodifferentiation, including root-finding, optimization (gradient descent, BFGS, and dataset compatability for optimizing mean squared error), and quadratic spline fitting. There is extensive documentation at the link below, and the project is publicly available for download via PyPI by running `pip install DeriveAlive`. Enjoy!

#### Documentation: https://cs-207-final-project-group-19.readthedocs.io/en/latest/
#### PyPI: https://pypi.org/project/DeriveAlive/#files
